.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install pinliner

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pinliner
    $ pip install pinliner
